@@ -8,11 +8,13 @@ from .views import Config, Profile
 
 from .share.views import ShareAPIView
 from .menus.views import MenuAPIView
+from .profile import UserViewSet
 
 # fmt: off
 router = BridgerRouter()
 router.register(r"frontenduserconfiguration", FrontendUserConfigurationModelViewSet, basename="frontenduserconfiguration")
 router.register(r"notification", NotificationModelViewSet, basename="notification")
+router.register(r"user", UserViewSet, basename="user")
 # fmt: on
 
 urlpatterns = [
@@ -22,7 +24,3 @@ urlpatterns = [
     path("share/", ShareAPIView.as_view(), name="share"),
     path("", include(router.urls)),
 ]
-
-
-def bundled_frontend(url):
-    return path(f"{url}", TemplateView.as_view(template_name="bridger/frontend.html"))
